#
# spec file for package pinentry
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define ncurses %(xxx="`readlink -f %{_includedir}/ncurses.h`"; echo $xxx)
%define nmajor  %(grep NCURSES_VERSION_MAJOR < %{_includedir}/ncurses.h)
%global flavor gui%{nil}
%if "%{flavor}" != ""
%define nsuffix -%{flavor}
%endif

%bcond_without fltk

Name:           pinentry%{?nsuffix}
Version:        1.3.1
Release:        1.1
Summary:        Collection of Simple PIN or Passphrase Entry Dialogs
License:        GPL-2.0-or-later
Group:          Productivity/Other
URL:            https://www.gnupg.org/aegypten/
Source:         https://www.gnupg.org/ftp/gcrypt/pinentry/pinentry-%{version}.tar.bz2
Source1:        https://www.gnupg.org/ftp/gcrypt/pinentry/pinentry-%{version}.tar.bz2.sig
# https://www.gnupg.org/signature_key.html
# https://incenp.org/srv/dgouttegattat.asc
Source2:        pinentry.keyring
Source3:        pinentry
Patch1:         pinentry-0.7.2-gtk+-2.4.diff
BuildRequires:  libassuan-devel >= 2.1.0
BuildRequires:  libgpg-error-devel >= 1.16
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
Provides:       pinentry-dialog
%if "%{flavor}" == "gui"
%if %{with fltk}
BuildRequires:  fltk-devel >= 1.3
%endif
BuildRequires:  pkgconfig(Qt6Core)
BuildRequires:  pkgconfig(Qt6Gui)
BuildRequires:  pkgconfig(Qt6Test)
BuildRequires:  pkgconfig(Qt6Widgets)
BuildRequires:  pkgconfig(gcr-3)
BuildRequires:  pkgconfig(gcr-base-3)
BuildRequires:  pkgconfig(gtk+-2.0) >= 2.12.0
BuildRequires:  pkgconfig(libsecret-1)
%ifnarch ppc
BuildRequires:  pkgconfig(efl)
%endif
%endif

%description
This is a collection of simple PIN or passphrase entry dialogs which
utilize the Assuan protocol as described by the Aegypten project.

%if "%{flavor}" == "gui"
%package -n pinentry-emacs
Summary:        Simple PIN or Passphrase Entry Dialog integrated into Emacs
Group:          Productivity/Other
Requires:       emacs
Requires:       pinentry
Provides:       pinentry-dialog
Provides:       pinentry-gui
Provides:       pinentry:%{_bindir}/pinentry-emacs

%description -n pinentry-emacs
A simple PIN or passphrase entry dialog utilize the Assuan protocol
as described by the Aegypten project, integrated into Emacs.

%package -n pinentry-efl
Summary:        Simple PIN or Passphrase Entry Dialog for EFL
Group:          Productivity/Other
Requires:       pinentry
Provides:       pinentry-dialog
Provides:       pinentry-gui
Provides:       pinentry:%{_bindir}/pinentry-efl

%description -n pinentry-efl
A simple PIN or passphrase entry dialog utilize the Assuan protocol
as described by the Aegypten project, using Enlightenment Foundation Libraries.

%package -n pinentry-gtk2
Summary:        Simple PIN or Passphrase Entry Dialog for GTK2
Group:          Productivity/Other
Requires:       pinentry
Provides:       pinentry-dialog
Provides:       pinentry-gui
Provides:       pinentry:%{_bindir}/pinentry-gtk-2

%description -n pinentry-gtk2
A simple PIN or passphrase entry dialog utilize the Assuan protocol
as described by the Aegypten project, using the GTK2 UI toolkit.

%package -n pinentry-gnome3
Summary:        Simple PIN or Passphrase Entry Dialog for GNOME
Group:          Productivity/Other
Requires:       pinentry
Provides:       pinentry-dialog
Provides:       pinentry-gui
Provides:       pinentry:%{_bindir}/pinentry-gnome3

%description -n pinentry-gnome3
A simple PIN or passphrase entry dialog utilize the Assuan protocol
as described by the Aegypten project, using GNOME libraries.

%if %{with fltk}
%package -n pinentry-fltk
Summary:        Collection of Simple PIN or Passphrase Entry Dialogs
Group:          Productivity/Other
Requires:       pinentry
Provides:       pinentry-dialog
Provides:       pinentry-gui
Provides:       pinentry:%{_bindir}/pinentry-fltk

%description -n pinentry-fltk
A simple PIN or passphrase entry dialog utilize the Assuan protocol
as described by the Aegypten project, using FLTK libraries.
%endif

%package -n pinentry-qt6
Summary:        Simple PIN or Passphrase Entry Dialog for QT5
Group:          Productivity/Other
Requires:       pinentry
Provides:       pinentry-dialog
Provides:       pinentry-gui
Provides:       pinentry-qt = %{version}
Obsoletes:      pinentry-qt <= 0.8.3
Provides:       pinentry-qt4 = %{version}-%{release}
Obsoletes:      pinentry-qt4 <= 0.9.7
Provides:       pinentry-qt5 = %{version}-%{release}
Obsoletes:      pinentry-qt5 <= 1.3.0

%description -n pinentry-qt6
A simple PIN or passphrase entry dialog utilize the Assuan protocol
as described by the Aegypten project, using the QT5 UI toolkit.
%endif

%prep
%autosetup -p1 -n pinentry-%{version}

%build
nmajor=$(sed -rn 's/^#define\s+NCURSES_VERSION_MAJOR\s+([0-9]+)/\1/p' %{_includedir}/ncurses.h)
CFLAGS="%{optflags} $(ncursesw${nmajor}-config --cflags)"
CXXFLAGS="%{optflags} $(ncursesw${nmajor}-config --cflags)"
LDFLAGS="$(ncursesw${nmajor}-config --libs)"
export CFLAGS CXXFLAGS LDFLAGS

%define _configure ../configure
%if "%{flavor}" == "gui"
# Regenerate moc's
# moc-qt6 qt/pinentrydialog.h > qt/pinentrydialog.moc
# moc-qt6 qt/pinentryconfirm.h > qt/pinentryconfirm.moc

# build gui version with libsecret (bnc#934214)
mkdir gui
cd gui
%configure \
	--disable-pinentry-curses \
	--disable-pinentry-tty \
	--enable-libsecret \
	--enable-pinentry-qt \
	--enable-pinentry-gtk2 \
	--enable-pinentry-gnome3 \
	--enable-pinentry-emacs \
	--enable-inside-emacs \
%if %{with fltk}
	--enable-pinentry-fltk \
%else
        --disable-pinentry-fltk \
%endif
	--enable-pinentry-efl \
	--without-ncurses-include-dir
%make_build
# build text version without libsecret (bnc#934214)
cd ..
%else
mkdir tui
cd tui
%configure \
	--enable-pinentry-curses \
	--enable-pinentry-tty \
	--disable-libsecret \
	--disable-pinentry-qt \
	--disable-pinentry-gtk2 \
	--disable-pinentry-gnome3 \
	--disable-pinentry-emacs \
	--disable-inside-emacs \
	--disable-pinentry-fltk \
	--disable-pinentry-efl \
	--without-ncurses-include-dir
%make_build
%endif

%install
%if "%{flavor}" == "gui"
cd gui
%make_install
cd ..

# backward compatibility symlinks
ln -s pinentry-qt %{buildroot}%{_bindir}/pinentry-qt6
ln -s pinentry-qt %{buildroot}%{_bindir}/pinentry-qt5
ln -s pinentry-qt %{buildroot}%{_bindir}/pinentry-qt4
rm -rf %{buildroot}%{_infodir}
rm -rf %{buildroot}%{_bindir}/pinentry
%else
cd tui
%make_install
cd ..

# remove symlink
rm -rf %{buildroot}%{_bindir}/pinentry
install -p -m 755 -D %{SOURCE3} %{buildroot}%{_bindir}/pinentry

%post
%install_info --info-dir=.%{_infodir} .%{_infodir}/pinentry.info.gz

%postun
%install_info_delete --info-dir=.%{_infodir} .%{_infodir}/pinentry.info.gz
%endif

%if "%{flavor}" == "gui"

%ifnarch ppc
%files -n pinentry-efl
%license COPYING
%attr(755,root,root) %{_bindir}/pinentry-efl
%endif

%files -n pinentry-emacs
%license COPYING
%attr(755,root,root) %{_bindir}/pinentry-emacs

%files -n pinentry-gtk2
%license COPYING
%attr(755,root,root) %{_bindir}/pinentry-gtk-2

%files -n pinentry-gnome3
%license COPYING
%attr(755,root,root) %{_bindir}/pinentry-gnome3

%if %{with fltk}
%files -n pinentry-fltk
%license COPYING
%attr(755,root,root) %{_bindir}/pinentry-fltk
%endif

%files -n pinentry-qt6
%license COPYING
%{_bindir}/pinentry-qt6
%{_bindir}/pinentry-qt5
%{_bindir}/pinentry-qt4
%attr(755,root,root) %{_bindir}/pinentry-qt
%{_datadir}/applications/org.gnupg.pinentry-qt.desktop
%{_datadir}/pixmaps/pinentry.png

%else

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_infodir}/pinentry*
%attr(755,root,root) %{_bindir}/pinentry
%attr(755,root,root) %{_bindir}/pinentry-tty
%attr(755,root,root) %{_bindir}/pinentry-curses

%endif

%changelog
* Wed Jul 17 2024 Alexander Graul <alexander.graul@suse.com>
- update to 1.3.1:
  * qt: Install and use pinentry icon. [rPf9c252a8d9]
  * qt: Small fix for Qt5. [rP844360c9c9]
  * qt: Fix Windows build of Qt6. [rP34019f954a]
  * New envvar PINENTRY_KDE_USE_WALLET to enable the secret
    storage integration on KDE. [rP23753cfb03]
* Sun Jun 30 2024 Dirk Müller <dmueller@suse.com>
- update to 1.3.0:
  * qt: Add new Qt6 frontend.  [rP1e79123c38]
  * qt: Set parent window on Wayland.  [T6930]
  * qt: Fix capslock detection on Wayland.  [rP7dfc60a70d]
  * qt: Fix window icon on Wayland.  [T6887]
  * qt: Add support for external password manager with libsecret.
  * qt: Remove focus indication by text selection.  [T5863]
  * qt: Use same focus indication for labels as Kleopatra.
  * qt: Improve accessibility.  [T5863]
  * gnome3: Prefer gcr-4.  [rP069c219223]
  * curses: Fix timeout handling.  [rP08408498b3]
  * curses: Add SETREPEATOK and quality bar colors.
  * curses: Add password quality meter.  [rP2923707e75]
  * curses,tty: Upon SIGINT, let pinentry exit gracefully.
  * w32: Fix non-focused window and simplify code.
  * Disable secret storage integration when running on KDE
    Plasma.
  * The Windows CE support has been removed.
* Thu Jun  1 2023 Frederic Crozat <fcrozat@suse.com>
- Update signature file and keyring with latest ones from download
  site, they were updated by another approved upstream maintainer.
* Mon Feb 27 2023 pgajdos@suse.com
- add %%bcond option to disable fltk backend
* Thu Aug 25 2022 Dirk Müller <dmueller@suse.com>
- update to 1.2.1:
  * qt: Support building with Qt 5.9.  [T5592]
  * curses: Handle an error at curses initialization.  [T5623]
  * curses: Specify fg/bg when an extention of Ncurses is not available.
  * qt: Fix translation of context menu entries.  [T5786]
  * qt: Further improve the accessibility.  [T5863]
  * qt: Fix moving focus to second input field when pressing Enter in
    first input field.  [T5866]
  * qt: Update the cursor position when reformatting the text.  [T5972]
  * qt: Use foreground raising code also with the confirm prompt.
  * Make the legacy qt4 version build again.  [T5569]
  * Make sure an entered PIN is always cleared from memory.  [T5977]
  * Build fixes for Windows.  [T5893]
* Thu Mar  3 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Correction for previous change: ensure the packages built in the
  gui flavor do not change their package name. e.g pinentry-qt5
  wrongly got renamed to pinentry-gui-qt5.
* Thu Feb 24 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Fix name tag for multibuild: name tag should be conditional on
  the multibuild flavor.
* Sat Aug 28 2021 Andreas Stieger <andreas.stieger@gmx.de>
- pinentry 1.2.0:
  * qt: Show a warning if Caps Lock is on
  * qt: Support password formatting.  This makes generated
    passwords easier to transcribe
  * qt: Fix showing of pinentry window on Wayland
  * qt: Check passphrase constraints before accepting passphrase
    if passphrase constraints are requested to be enforced
  * qt: Improve detection of running in a GUI session
  * qt: Improve accessibility when entering new password
* Fri Jan 29 2021 Dirk Müller <dmueller@suse.com>
- add _multibuild to separate out gui client builds
* Wed Jan 27 2021 Andreas Stieger <andreas.stieger@gmx.de>
- actually build efl based pinentry
- re-enable validation of upstream signing key
* Sun Jan 24 2021 Dirk Müller <dmueller@suse.com>
- update to 1.1.1:
  * A EFL-based pinentry has been contributed.
  * Disable echoing in backspace key is pressed first
    (GTK, Qt, TQt, and ncurses pinentries).
  * Support line editing in TTY pinentry.
  * Remove support for old GTK+2 (< 2.12.0).
  * Various minor fixes.
- drop pinentry-qt-Fix-use-of-dangling-pointer.patch (upstream)
- drop pinentry-ncurses6.diff: obsolete
* Thu Jul 25 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Fix a dangling pointer in qt/main.cpp [bsc#1141883]
  * Added pinentry-qt-Fix-use-of-dangling-pointer.patch
* Thu Jul 25 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Updated spec file with spec-cleaner
* Thu Feb 22 2018 fvogt@suse.com
- Use %%license (boo#1082318)
* Mon Dec 11 2017 astieger@suse.com
- pinentry 1.1.0:
  * Add FLTK1.3-based pinentry
  * New option --ttyalert for pinentry-curses to alert the user.
  * Don't show "save passphrase" checkbox if secret service is
    unavailable.
  * The GTK Pinentry shows on Linux some information anout the
    process which invoked the Pinentry.
  * The GTK Pinentry does not anymore show tooltips when keyboard
    grabbing is enabled.
* Thu Dec 15 2016 tchvatal@suse.com
- Build pinentry tui in build and not during install
* Wed Dec 14 2016 astieger@suse.com
- pinentry 1.0.0:
  * Qt pinentry now supports repeat mode in one dialog.
  * Qt and GTK pinentries now make it possible to show the entered
    value.
  * Qt pinentry now only grabs the keyboard if an entry field is
    focused.
  * Fixed potential crash in Qt qualitybar calculation.
  * GTK keyboard grabbing is now a bit more robust.  The cursor is
    changed to a big dot as a visual indication that a pinentry
    has popped up and is waiting for input.
  * The GNOME pinentry now falls back to curses if it can't use the
    GCR system prompter or a screenlock is active.
  * Fixed error output for cached passwords.
  * A show/hide passphrase button or checkbox is now available with
    some pinentry flavors.
  * Improved diagnostics and error codes.
* Fri Jul 29 2016 tchvatal@suse.com
- Update the conflict to bring back the self-deprecation broken in
  previous change wrt boo#989554
* Wed Jan 20 2016 astieger@suse.com
- completely rename to qt5 [boo#962076]
- fix self-deprecation rpmlint warning
* Wed Jan 13 2016 tchvatal@suse.com
- Use qt5 instead of qt4 in pinentry-qt
* Mon Dec 14 2015 andreas@suse.de
- pinentry 0.9.7:
  * Fix regressions in the Qt pinentry.
  (previsouly patched, removed
  pinentry-qt4-fix-qstring-conversion.patch)
  * Fix minor problems pinnetyr-tty.
  * New option --invisible-char.
* Wed Oct 21 2015 dmueller@suse.com
- add pinentry-qt4-fix-qstring-conversion.patch (bsc#951307)
* Tue Oct  6 2015 kstreitova@suse.com
- update to 0.9.6
  * changelog:
    + Many improvements for the dump tty pinentry
    + Use the standard GTK+-2 text entry widget instead of our outdated
    and back-then-it-was-more-secure text widget
    + Use the standard Qt text widget
    + Allow for building a static Qt variant
    + Fix regression in w32 pinentry
  * remove qt4-disable-inputmethod-for-passwords.diff (patched file
    is no longer present)
  * remove regenerating of qt4/qsecurelineedit.moc in specfile as
    qt4/qsecurelineedit.h was deleted. Adjust paths for the rest
    of the moc files (qt4 -> qt).
  * '--enable-pinentry-qt4' is now '--enable-pinentry-qt'
  * '--enable-pinentry-qt4-clipboard' option was removed
  * add backward compatibility link for pinentry-qt4
- use spec-cleaner
* Fri Jul 10 2015 werner@suse.de
- Make it build with every ncurses library ABI
  adding pinentry-ncurses6.diff
* Wed Jul  1 2015 astieger@suse.com
- pinentry 0.9.5:
  * Replaced the internal Assuan and gpg-error code by the standard
    libassuan and libgpg-error libraries.
  * Add a new Emacs pinentry and use as fallback for GUI programs.
  * gnome3: The use-password-manager checkbox does now work.
  * Gtk: Improved fallback to curses feature.
  * curses: Recognize DEL as backspace.
* Thu Jun 11 2015 lnussel@suse.de
- build gui version with libsecret and text mode versions without to
  avoid pulling in dbus-x11 on minimal installs (bnc#934214)
* Wed Jun 10 2015 astieger@suse.com
- pinentry 0.9.4:
  * Fix regression in GTK+ and curses pinentries [boo#934207]
* Fri Jun  5 2015 astieger@suse.com
- No longer increase the default secure memory size from 16k to 64k,
  as further memory would be locked from being paged to disk by the
  pinentry-gnome3 UI, generating an error message and failing to
  lock. Remove moreSecureMemoryForPinentry-qt.diff - [boo#933687]
* Thu Jun  4 2015 astieger@suse.com
- pinentry 0.9.3:
  * new pinentry-gnome3
  * Improved documentation
  * More improvements for pinentry-tty.
  * Fixes for pinentry-curses including support for Ctrl-W, Ctrl-U,
    Ctrl-H, Ctrl-L, and Alt-Backspace
  * New Assuan command to request clearing an external cache.
  * Fixed problems linking to ncursesw.
  * All kind of other minor fixes.
- update pinentry script to use gnome3 if installed, no automation
- Enabled features:
  * Support for saving the passphrase with libsecret.
* Tue May 12 2015 astieger@suse.com
- pinentry 0.9.2:
  * Escape key works in the Gtk+ pinentry.
  * Improvements for pinentry-tty.
- Upstream supported but not enabled:
  * Support for saving the passphrase with libsecret.
* Thu Mar 26 2015 astieger@suse.com
- qt4 pasting was available upstream since 0.8.4 but not enabled.
  Enable through configure option [boo#905155]
* Mon Mar 23 2015 crrodriguez@opensuse.org
- Use -std=gnu++11 in CXXFLAGS, fix build with gcc5.
* Thu Mar 19 2015 astieger@suse.com
- pinentry 0.9.1:
  * Fixed build problems for systems without ncurses.
  * Reworked the option parser to allow building on systems without
  getopt_long.
  * Fixed Qt4 build problems.
* Sat Nov  1 2014 andreas.stieger@gmx.de
- pinentry 0.9.0:
  * New command SETREPEAT.  Currently only supported for Gtk+-2.
  * Gtk+-2: Pasting using the mouse is now supported.
  * curses: Check that it is actually connected to a tty.
  * Removed the old qt-3 and gtk+-1 pinentries.
- remove obsolete patches:
  pinentry-0.7.2-bnc179996_disable_inputmethod_for_passords.patch
  pinentry-0.8.1-allow_paste_gtk2.patch
- remove build dependencies and autoconf call, removing patch
  pinentry-0.8.1-tinfo.patch
* Tue Oct 21 2014 tchvatal@suse.com
- Remove qt3 helpers
- Remove gpg verification in spec, it is done by obs automatically
- Some whitespace changes
- Add default defattr
* Sun Sep 21 2014 andreas.stieger@gmx.de
- pinentry 0.8.4:
  * New pinentry-tty version for dumb terminals.
  * Qt4: New option to enable pasting the passphrase from clipboard
  * Qt4: Improved accessiblity
  * Qt4: Raise confirm message windows into foreground
  * Improved the build system.
- remove pinentry-0.8.1-allow_paste_qt4.patch, functionality
  implemented
- sync pinentry wrapper with Fedora
- update pinentry wrapper to use pinentry-tty on dumb terminals
* Sat Dec 21 2013 coolo@suse.com
- disable qt3 support to avoid maintaining qt3 forever
* Mon Aug 19 2013 andreas.stieger@gmx.de
- update to 0.8.3
  * Add SETTIMEOUT command for the gtk+-2 pinentry.
- includes changes from 0.8.2:
  * New SETTIMEOUT command for the qt4 pinentry.
  * Wide character support for the curses pinentry.
    ( already present in openSUSE patched version)
  * Various bug fixes.
- drop pinentry-0.7.2-curses-utf-8.diff, implemented upstream
- drop pinentry-0.8.1-editing-cancelled_warning.patch, same
- refresh qt4-disable-inputmethod-for-passwords.diff
* Mon Apr 22 2013 meissner@suse.com
- %%makeinstall instead of %%make install.
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
- Add GPG checking
* Mon Dec  5 2011 vcizek@suse.com
- fixed licence of the pinentry-qt subpackage (bnc#734792)
* Wed Nov 30 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Nov 22 2011 vcizek@suse.com
- patch that fixes Glib warning (bnc#730453)
- add -ltinfo to fix build
* Fri Oct 21 2011 tiwai@suse.de
- fix pinentry-qt4 not to allow triggering IM (bnc#725471)
* Wed Sep 14 2011 vcizek@suse.com
- enable paste for pinentry-gtk2 (bnc#690514)
* Tue Sep 13 2011 vcizek@suse.com
- enable paste for pinentry-qt4 (bnc#690514)
* Thu Mar 24 2011 puzel@novell.com
- update to pinentry-0.8.1
  * The GTK pinentry now always sticks to the top and properly grabs
  the keyboard.
  * The protocol options default-cancel and default-ok now work for
  the pinentry-gtk2 and pinentry-qt (that is QT3).
- drop pinentry-qt-fix-1162.diff (in upstream)
- use spec-cleaner
* Tue Oct  5 2010 cristian.rodriguez@opensuse.org
- Add missing buildrequires on libcap-devel
* Mon Aug 23 2010 puzel@novell.com
- pinentry-qt-fix-1162.diff: fix active window issue (bnc#629502)
  Upstream Patch: https://bugs.g10code.com/gnupg/issue1162
* Wed Jul  7 2010 puzel@novell.com
- change pinentry script to not to rely on curses fallback
  mechanism if DISPLAY is not set
* Wed Mar 17 2010 puzel@novell.com
- update to pinentry-0.8.0
  * Beautified the qt4 pinentry
  * Minor enhancements.
* Sat Dec 19 2009 jengelh@medozas.de
- enable parallel build
* Wed Oct  7 2009 puzel@novell.com
- do not fail when no graphical pinentry is installed -
  try pinentry-curses instead (bnc#544365)
* Fri Aug 21 2009 puzel@novell.com
- all graphical pinentry (-qt,qt4,-gtk2) now provide pinentry-gui
* Tue Jun 30 2009 puzel@novell.com
- improve pinentry script: prefer pinentry-qt in KDE3 environment
  (bnc#514688)
* Wed Jun 24 2009 puzel@novell.com
- update to pinentry-0.7.6
  * Make Gtk+-2 pinentry transient to the root window.
  * Add Qt4 pinentry.
  * Fix utf-8 problem in Qt pinentries.
  * Return GPG_ERR_CANCELED if during a "CONFIRM" command the user
    closed the window.
  * Add quality bar.
- drop pinentry-gsize.patch (fixed in upstream)
- drop wrong-apostrophe.patch (fixed in upstream)
- drop pinentry-qt4.patch (native qt4 support added)
- simplify build section with configure macro and autoreconf
* Thu May 28 2009 puzel@suse.cz
- pinentry-qt4 (bnc#505134)
  - add pinentry-qt4.patch.bz2
* Mon Nov 10 2008 coolo@suse.de
- revert the last entry (reopened the bug)
* Wed Nov  5 2008 puzel@suse.cz
- pinentry requires pinentry-dialog (bnc#441084)
* Wed Jul 23 2008 puzel@suse.cz
- added pinentry-0.7.5-wrong-apostrophe.patch
  * fixes (bnc#411312)
* Mon Jun 16 2008 puzel@suse.cz
- removed pinentry-0.7.2-qt-utf8.diff workaround patch
  (not needed since [bnc#305725] is fixed)
* Wed Apr 16 2008 pcerny@suse.cz
- update to 0.7.5
  (small fixes, see package's changelog for details)
* Thu Apr 10 2008 werner@suse.de
- Use correct ncurses header for libncursesw
- Handle info file
- Use RPM_OPT_FLAGS even for c++ files
* Sun Mar 30 2008 ro@suse.de
- fix build with changed definition of g_malloc (gulong->gsize)
* Tue Sep 11 2007 ltinkl@suse.cz
- fix various utf-8 problems (#305725)
* Thu Mar 29 2007 ro@suse.de
- added ncurses-devel to buildreq
* Fri Jan  5 2007 anicka@suse.cz
- fix KDE detection in pinentry wrapper script
  (thanks llunak for a patch)
* Wed Nov 22 2006 anicka@suse.cz
- fixed Provides [#223074]
* Tue Nov 21 2006 nadvornik@suse.cz
- fixed pinentry script: dont use pinentry-curses in GUI [#205688]
- removed useless provides
* Mon Nov  6 2006 anicka@suse.de
- split graphical frontends (#217373)
- rewrite pinentry wrapper to use the right binary
* Mon Nov  6 2006 pnemec@suse.cz
- Fixed pinnentry wrapper #218257
* Sun Oct 15 2006 schwab@suse.de
- Make sure config.rpath is present.
* Tue Oct  3 2006 pnemec@suse.cz
- removed static simlink to pinentry-qt
- add script which use pinentry-qt only when KDE is detected
* Mon Jun 26 2006 mfabian@suse.de
- Bugzilla #179996: enable input methods in SecQlineEdit widgets
  only when "mode == Normal" (i.e. not when "mode == NoEcho" or
  "mode == Password"). Using input methods while inputting
  passwords is useless. See also Bugzilla #117115.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 ro@suse.de
- added symlink to filelist
* Fri Jul 29 2005 anicka@suse.cz
- update to 0.7.2
- remove part of gtk2 patch contained in new version
* Tue Nov  2 2004 postadal@suse.cz
- added patch gtk+-2.4.diff.bz2 for gtk2 support (removing gtk1 dependency)
* Tue Jul 13 2004 adrian@suse.de
- update to version 0.7.1
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Tue Nov 18 2003 mc@suse.de
- increase secmem allocation for pinentry-qt to avoid
  "Out of memory" errors.
  (pinentry-0.6.9.moreSecureMemoryForPinentry-qt.diff)
* Mon Jun  2 2003 mc@suse.de
- remove pinentry-0.6.8-prevent-assuan-stderr.dif; no longer needed
- switch to version 0.6.9
  * a memory-issue present in 0.6.8
  * a minor build problem (make distclean now cleans up .moc files)
  * assuan protocol debug messages are not written to stderr
- fixed build on x86_64
* Tue Apr  8 2003 mc@suse.de
- prevent pinentry-qt to print the assuan protocol to stderr
* Fri Feb 21 2003 ro@suse.de
- fixed neededforbuild
* Tue Feb 11 2003 mc@suse.de
- initial release
